from .base_enums import AvatarPart


class HairType(AvatarPart):
    """Hair types"""

    __install__ = True
    __enum_path__ = 'hair_types.py'
    __path__ = 'avatar_parts/top/hair'

    NONE = 'no_hair'
    BIG_HAIR = 'big_hair'
    BOB = 'bob'
    BUN = 'bun'
    CAESAR_SIDE_PART = 'caesar_side_part'
    CAESAR = 'caesar'
    CURLY = 'curly'
    CURVY = 'curvy'
    DREADS = 'dreads'
    FRIDA = 'frida'
    FRIZZLE = 'frizzle'
    FRO_BAND = 'fro_band'
    FRO = 'fro'
    LONG_NOT_TOO_LONG = 'long_not_too_long'
    MIA_WALLACE = 'mia_wallace'
    SHAGGY_MULLET = 'shaggy_mullet'
    SHAGGY = 'shaggy'
    SHAVED_SIDES = 'shaved_sides'
    SHORT_CURLY = 'short_curly'
    SHORT_DREADS_1 = 'short_dreads_1'
    SHORT_DREADS_2 = 'short_dreads_2'
    SHORT_FLAT = 'short_flat'
    SHORT_ROUND = 'short_round'
    SHORT_WAVED = 'short_waved'
    SIDES = 'sides'
    STRAIGHT_1 = 'straight_1'
    STRAIGHT_2 = 'straight_2'
    STRAIGHT_STRAND = 'straight_strand'
