from .base_enums import AvatarPart


class NoseType(AvatarPart):
    """Nose types"""

    __install__ = True
    __enum_path__ = 'nose_types.py'
    __path__ = 'avatar_parts/nose'

    DEFAULT = 'default'
